@@ -9,7 +9,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 
 sub error
@@ -498,6 +498,17 @@ Image::PNG - Read and write PNG files
     $png->read_file ("crazy.png");
     printf "Your PNG is %d x %d\n", $png->width, $png->height;
 
+=head1 DESCRIPTION
+
+Image::PNG is a layer on top of L<Image::PNG::Libpng>. Whereas
+L<Image::PNG::Libpng> copies the interface of the C library C<libpng>,
+Image::PNG is intended to be a more intuitive way to handle PNG
+images. 
+
+Please note that this module is not completed yet and is still under
+development, so the interface may change. It's also open to
+suggestions for improvements.
+
 =head1 General methods
 
 =head2 new
@@ -685,7 +696,8 @@ general-purpose routine.
 
 =head1 SUPPORT
 
-There is a mailing list for this Perl module at Google Groups. If you
+There is L<a mailing list for this Perl module at Google
+Groups|https://groups.google.com/forum/#!forum/perlimagepng>. If you
 have an enquiry, post to the mailing list. You don't have to join the
 mailing list to post a message.
 
@@ -748,6 +760,20 @@ palette, gamma (gAMA chunk), resolution (pHYs chunk), and significant
 bits (sBIT chunk). At the time of writing (version 1.31) it doesn't
 support other chunks.
 
+=head3 Image::Size
+
+If you only need to find the size of an image, L<Image::Size> can give
+you the size of PNG and various other image formats. This module is
+highly recommended on CPAN ratings.
+
+=head3 Image::PNGwriter
+
+L<Image::PNGwriter> is an interface to a project called
+"PNGwriter". At the time of writing (2013-12-01), only one version has
+been released, in 2005. The most recent version of PNGwriter itself is
+from 2009.
+
+
 
 
 =head2 About the PNG format
@@ -798,7 +824,7 @@ Ben Bullock, <bkb@cpan.org>
 =head1 COPYRIGHT & LICENCE
 
 The Image::PNG package and associated files are copyright (C)
-2013 Ben Bullock.
+2014 Ben Bullock.
 
 You can use, copy, modify and redistribute Image::PNG and
 associated files under the Perl Artistic Licence or the GNU General
